module debounce (
		 clk,
		 reset_n,
		 in,
		 out,
		 strobe
		 );
   input  clk;
   input  reset_n;
   input  in;
   output out;
   output strobe;

   // This is optimized for a 12.5 MHz clock and the
   // assumption that glitches are limited to 20 us

   reg 	     out;
   reg 	     out1;
   reg [7:0] ctr;

   assign    strobe = out ^ out1;
   
   always @(negedge reset_n or posedge clk)
     if ( ~reset_n )
       begin
	  out <= 0;
	  out1 <= 0;
	  ctr <= 0;
       end
     else
       begin
	  out1 <= out;
	  
	  if ( in )
	    begin
	       if ( ctr == 8'hFF )
		 out <= 1'b1;
	       else
		 ctr <= ctr + 1;
	    end
	  else
	    begin
	       if ( ctr == 8'h00 )
		 out <= 1'b0;
	       else
		 ctr <= ctr - 1;
	    end
       end // else: !if( ~reset_n )

endmodule // debounce
	